@@ -74,10 +74,27 @@ parse_input = {'boolean': parse_bool,
                'app': (lambda string: {'$dnanexus_link': string}),
                'table': (lambda string: parse_obj(string, 'table'))}
 
+def _construct_jbor(job_id, field_name_and_maybe_index):
+    '''
+    :param job_id: Job ID
+    :type job_id: string
+    :param field_name_and_maybe_index: Field name, plus possibly ".N" where N is an array index
+    :type field_name_and_maybe_index: string
+    :returns: dict of JBOR
+    '''
+    link = {"$dnanexus_link": {"job": job_id}}
+    if '.' in field_name_and_maybe_index:
+        split_by_dot = field_name_and_maybe_index.rsplit('.', 1)
+        link["$dnanexus_link"]["field"] = split_by_dot[0]
+        link["$dnanexus_link"]["index"] = int(split_by_dot[1])
+    else:
+        link["$dnanexus_link"]["field"] = field_name_and_maybe_index
+    return link
+
 def parse_input_or_jbor(in_class, value):
     val_substrings = split_unescaped(':', value)
     if len(val_substrings) == 2 and (is_job_id(val_substrings[0]) or is_localjob_id(val_substrings[0])):
-        return {"job": val_substrings[0], "field": val_substrings[1]}
+        return _construct_jbor(val_substrings[0], val_substrings[1])
     else:
         if in_class.startswith('array:'):
             in_class = in_class[6:]
@@ -93,7 +110,7 @@ def print_param_help(param_desc):
 def interactive_help(in_class, param_desc, prompt):
     is_array = param_desc['class'].startswith("array:")
     print_param_help(param_desc)
-    print
+    print()
     array_help_str = ', or <ENTER> to finish the list of inputs'
     if in_class in dx_data_classes:
         # Class is some sort of data object
@@ -143,7 +160,7 @@ def interactive_help(in_class, param_desc, prompt):
                 result_generator = dxpy.find_jobs(project=dxpy.WORKSPACE_ID,
                                                   describe=True,
                                                   parent_job="none")
-                print
+                print()
                 print('Previously-run jobs to choose from:')
                 result_choice = paginate_and_pick(result_generator,
                                                   (lambda result: get_find_executions_string(result['describe'],
@@ -214,7 +231,7 @@ def get_input_array(param_desc):
     print('Class:   ' + param_desc['class'])
     if 'type' in param_desc:
         print('Type(s): ' + parse_typespec(param_desc['type']))
-    print
+    print()
 
     prompt = "Enter {_class} values, one at a time (^D or <ENTER> to finish, {hint}'" + WHITE() + BOLD() + '?' + ENDC() + "' for more options)"
     hint = ''
@@ -317,7 +334,7 @@ def get_input_single(param_desc):
         print(format_choices_or_suggestions('Suggestions:', param_desc['suggestions'], param_desc['class'], initial_indent='', subsequent_indent='  '))
     if 'choices' in param_desc:
         print(format_choices_or_suggestions('Choices:', param_desc['choices'], param_desc['class'], initial_indent='', subsequent_indent='  '))
-    print
+    print()
 
     prompt = "Enter {_class} {value} ({hint}'" + WHITE() + BOLD() + '?' + ENDC() + "' for more options)"
     hint = ''
@@ -451,7 +468,7 @@ class ExecutableInputs(object):
                 # Resolve "job-xxxx:output-name" syntax into a canonical job ref
                 job_id, field = split_unescaped(':', input_value)
                 if is_job_id(job_id) or is_localjob_id(job_id):
-                    input_value = {"job": job_id, "field": field}
+                    input_value = _construct_jbor(job_id, field)
                     done = True
             except:
                 pass
