@@ -183,16 +183,34 @@ def get_field_from_jbor(thing):
     else:
         return thing['field']
 
+def get_index_from_jbor(thing):
+    '''
+    :returns: Array index of the JBOR if applicable; None otherwise
+
+    Assumes :func:`is_job_ref` evaluates to True
+    '''
+    if '$dnanexus_link' in thing:
+        return thing['$dnanexus_link'].get('index')
+    else:
+        return None
+
 def is_metadata_ref(thing, reftype=dict):
     return isinstance(thing, reftype) and \
         len(thing) == 1 and \
         isinstance(thing.get('$dnanexus_link'), reftype) and \
         isinstance(thing['$dnanexus_link'].get('metadata'), basestring)
 
+def jbor_to_str(val):
+    ans = get_job_from_jbor(val) + ':' + get_field_from_jbor(val)
+    index = get_index_from_jbor(val)
+    if index is not None:
+        ans += "." + str(index)
+    return ans
+
 def io_val_to_str(val):
     if is_job_ref(val):
         # Job-based object references
-        return get_job_from_jbor(val) + ':' + get_field_from_jbor(val)
+        return jbor_to_str(val)
     elif isinstance(val, dict) and '$dnanexus_link' in val:
         # DNAnexus link
         if isinstance(val['$dnanexus_link'], basestring):
@@ -249,7 +267,7 @@ def get_io_field(io_hash, defaults=None, delim='=', highlight_fields=()):
 
 def get_resolved_jbors(resolved_thing, orig_thing, resolved_jbors):
     if is_job_ref(orig_thing):
-        resolved_jbors[get_job_from_jbor(orig_thing) + ':' + get_field_from_jbor(orig_thing)] = resolved_thing
+        resolved_jbors[jbor_to_str(orig_thing)] = resolved_thing
     elif isinstance(orig_thing, list):
         for i in range(len(orig_thing)):
             get_resolved_jbors(resolved_thing[i], orig_thing[i], resolved_jbors)
